@@ -87,10 +87,11 @@ if __name__ == '__main__':
         imagename (string) --> the name you wish to use for the newly-created container image
         """
         commands = ['FROM alpine' + "\n",
-        "RUN apt-get update -y && apt-get install -y python-pip python-dev python-jinja2 python-flask" + "\n",
+        "RUN apt-get update -y && apt-get install -y python-pip python-dev python-jinja2 python-flask python-sklearn" + "\n",
         "COPY ./requirements.txt /app/requirements.txt" + "\n",
         "WORKDIR /app" + "\n",
         "RUN pip install -r requirements.txt" + "\n",
+        "RUN pip install --upgrade setuptools" + "\n",
         "COPY {} /app".format(self.entry_file) + "\n",
         "COPY {} /app".format(self.model_path) + "\n",
         "COPY {} /app".format(self.requirements) + "\n",
